@@ -176,7 +176,7 @@ def create_function_from_folder(
         )
     except CogniteNotFoundError:
         logging.info(
-            f"Function {human_readable_name} with external id {function_name} does not already exist"
+            f"Function {human_readable_name} with external id {function_name} does not exist"
         )
         pass
     
