@@ -78,7 +78,10 @@ def deploy_model(model_settings, platform_methods=platform_methods):
 
             artifact_external_id = model_name + "/" + env 
             artifact_versions = cdf.query_file_versions(directory_prefix="/mlops", external_id_prefix=artifact_external_id)
-            latest_artifact_version = artifact_versions.loc[artifact_versions.uploadedTime.argmax()].metadata["version"]
+            if len(artifact_versions) == 0: 
+                latest_artifact_version = 1
+            else:
+                latest_artifact_version = artifact_versions.loc[artifact_versions.uploadedTime.argmax()].metadata["version"]
             logging.info(f"Latest artifact version in {env} environment is {latest_artifact_version}")
             external_id = function_name + "-" + str(latest_artifact_version)
         else: 
