@@ -80,8 +80,11 @@ def copy_to_deployment_folder(list, deployment_folder):
         - deployment_folder: (Path) 
     """
     for k,v in list.items():
-        logging.debug(f"{k} => deployment folder")
-        to_folder(v, deployment_folder)
+        if v:
+            logging.debug(f"{k} => deployment folder")
+            to_folder(v, deployment_folder)
+        else:
+            logging.warning(f"{k} has no value")
 
 
 def install_requirements(req_file):
