@@ -113,7 +113,7 @@ def find_model_version(model_name, env, metadata):
     )
 
     if (n_models := file_list.shape[0]) == 0:
-        message = f"No model artifacts found for model with {model_name=} in {env=} and metadata {metadata}. Upload/promote artifacts or specify the correct model name before redeploying"
+        message = f"No model artifacts found for model with {model_name=}, {env=} and metadata {metadata}. Upload/promote artifacts or specify the correct model name before redeploying"
         raise Exception(message)
     elif n_models > 1:
         logging.debug(f"Found {n_models} model artifact folders, deploy using the latest")
